# PyDAQmx

This package provides an interface in Python for the National Instruments DAQmx driver.
It has been tested with different version of NI-DAQmx (starting from 8.01) and on Windows XP and 
Windows 7. It works with Python 2 (from 2.7) and Python 3. 


## Installation

To install this package:

1. Install the NI-DAQmx driver. 
2. Run `python setup.py install`.


## License

This software can be used under one of two licenses:

1. The BSD license. 
2. Any other license, as long as it is obtained from the original author.
